@@ -1,7 +1,9 @@
 """Module to handle annotation-related operations within a project."""
+
 import sys
 from matrice.utils import handle_response
-from datetime import datetime, timedelta
+from datetime import datetime
+
 
 class Annotation:
     """
@@ -56,59 +58,53 @@ class Annotation:
     >>> print(annotation.version_status)
     """
 
-
-    def __init__(self, session, annotation_id=None, annotation_name=None):
+    def __init__(
+        self,
+        session,
+        annotation_id=None,
+        annotation_name=None,
+    ):
+        self.session = session
         self.project_id = session.project_id
         self.annotation_id = annotation_id
         self.annotation_name = annotation_name
         self.rpc = session.rpc
-        assert annotation_id or annotation_name, "Either annotation_id or annotation_name must be provided"
-
-        # Fetch annotation by name only if only annotation_name is provided
+        assert (
+            annotation_id or annotation_name
+        ), "Either annotation_id or annotation_name must be provided"
         annotation_by_name, err, msg = self._get_annotation_by_name()
         if self.annotation_id is None:
             if annotation_by_name is None:
                 raise ValueError(f"Annotation with name '{self.annotation_name}' not found.")
-            
-            self.annotation_id = annotation_by_name['_id']
-        
-        # If both annotation_id and annotation_name are provided, check for mismatch
+            self.annotation_id = annotation_by_name["_id"]
         elif self.annotation_id is not None and self.annotation_name is not None:
-            fetched_annotation_id = annotation_by_name['_id']
-                
+            fetched_annotation_id = annotation_by_name["_id"]
             if fetched_annotation_id != self.annotation_id:
-                raise ValueError("Provided annotation_id does not match the annotation id of the provided annotation_name.")
-
-        self.annotation_details, error, message = self._get_details()
+                raise ValueError(
+                    "Provided annotation_id does not match the annotation id of the provided annotation_name."
+                )
+        (
+            self.annotation_details,
+            error,
+            message,
+        ) = self._get_details()
         print(self.annotation_details)
-        self.version_status = self.annotation_details.get('status')
-        self.latest_version = self.annotation_details.get('datasetVersion')
-        self.last_updated_at = self.annotation_details.get('updatedAt')
-        self.project_type = self.annotation_details.get('projectType')
-        
+        self.version_status = self.annotation_details.get("status")
+        self.latest_version = self.annotation_details.get("datasetVersion")
+        self.last_updated_at = self.annotation_details.get("updatedAt")
+        self.project_type = self.annotation_details.get("projectType")
 
     def refresh(self):
         """
         Refresh the instance by reinstantiating it with the previous values.
         """
-        # Check if two minutes have passed since the last refresh
-        if datetime.now() - self.last_refresh_time < timedelta(minutes=2):
-            raise Exception("Refresh can only be called after two minutes since the last refresh.")
-
-        # Capture the current state
-        state = self.__dict__.copy()
-
         init_params = {
-            'session': self.session,
-            'annotation_id': self.annotation_id,
+            "session": self.session,
+            "annotation_id": self.annotation_id,
         }
-
-        # Reinitialize the instance
         self.__init__(**init_params)
-
-        # Update the last refresh time
         self.last_refresh_time = datetime.now()
-                
+
     def _get_details(self):
         """
         Retrieve detailed information for an annotation based on the provided annotation ID or name.
@@ -129,9 +125,9 @@ class Annotation:
                 - `datasetVersion` (str): Dataset version associated with the annotation.
                 - `updatedAt` (str): Last update timestamp for the annotation.
                 - `projectType` (str): Type of project associated with the annotation.
-            - str or None: 
+            - str or None:
                 Error message if an error occurred, `None` otherwise.
-            - str: 
+            - str:
                 Status message indicating success or failure.
 
         Raises
@@ -155,7 +151,6 @@ class Annotation:
         """
         id = self.annotation_id
         name = self.annotation_name
-
         if id:
             try:
                 return self._get_annotation_by_id()
@@ -187,9 +182,9 @@ class Annotation:
                 - `datasetVersion` (str): Dataset version associated with the annotation.
                 - `updatedAt` (str): Timestamp of the last update for the annotation.
                 - `projectType` (str): Type of project associated with the annotation.
-            - str or None: 
+            - str or None:
                 Error message if an error occurred, `None` otherwise.
-            - str: 
+            - str:
                 Status message indicating success or failure.
 
         Example
@@ -203,9 +198,10 @@ class Annotation:
         """
         path = f"/v1/annotations/{self.annotation_id}"
         resp = self.rpc.get(path=path)
-
         return handle_response(
-            resp, "Annotation fetched successfully", "Could not fetch annotation"
+            resp,
+            "Annotation fetched successfully",
+            "Could not fetch annotation",
         )
 
     def _get_annotation_by_name(self):
@@ -224,9 +220,9 @@ class Annotation:
                 - `datasetVersion` (str): Dataset version associated with the annotation.
                 - `updatedAt` (str): Timestamp of the last update for the annotation.
                 - `projectType` (str): Type of project associated with the annotation.
-            - str or None: 
+            - str or None:
                 Error message if an error occurred, `None` otherwise.
-            - str: 
+            - str:
                 Status message indicating success or failure.
 
         Example
@@ -245,13 +241,12 @@ class Annotation:
             sys.exit(0)
         path = f"/v1/annotations/get_annotation_by_name?annotationName={self.annotation_name}"
         resp = self.rpc.get(path=path)
-
         return handle_response(
             resp,
             "Annotation by name fetched successfully",
             "Could not fetch annotation by name",
         )
-    
+
     def rename(self, annotation_title):
         """
         Rename the annotation with the specified title. The annotation ID must be set in the class instance.
@@ -265,11 +260,11 @@ class Annotation:
         -------
         tuple
             A tuple containing three elements:
-            - dict: 
+            - dict:
                 The API response confirming the annotation title update.
-            - str or None: 
+            - str or None:
                 Error message if an error occurred, `None` otherwise.
-            - str: 
+            - str:
                 Status message indicating success or failure.
 
         Raises
@@ -291,18 +286,20 @@ class Annotation:
                 "Dataset id not set for this dataset. Cannot perform the operation for dataset without dataset id"
             )
             sys.exit(0)
-
         path = f"/v1/annotations/{self.annotation_id}"
         headers = {"Content-Type": "application/json"}
         body = {"title": annotation_title}
-        resp = self.rpc.put(path=path, headers=headers, payload=body)
-
+        resp = self.rpc.put(
+            path=path,
+            headers=headers,
+            payload=body,
+        )
         return handle_response(
             resp,
             "Update data item label in progress",
             "Could not update the date item label",
         )
-    
+
     def delete(self):
         """
         Delete the entire annotation task. The `annotation_id` and `project_id` must be set in the class instance.
@@ -311,11 +308,11 @@ class Annotation:
         -------
         tuple
             A tuple containing three elements:
-            - dict: 
+            - dict:
                 The API response confirming the annotation deletion.
-            - str or None: 
+            - str or None:
                 Error message if an error occurred, `None` otherwise.
-            - str: 
+            - str:
                 Status message indicating success or failure.
 
         Raises
@@ -337,21 +334,17 @@ class Annotation:
                 "Annotation id not set for this dataset. Cannot perform the deletion for annotation without annotation id"
             )
             sys.exit(0)
-
-        path = (
-            f"/v1/annotations/{self.annotation_id}?projectId={self.project_id}"  # check
-        )
-
+        path = f"/v1/annotations/{self.annotation_id}?projectId={self.project_id}"
         resp = self.rpc.delete(path=path)
         return handle_response(
             resp,
             "Annotation deleted successfully",
             "An error occured while deleting annotation",
         )
-    
+
     def get_annotation_files(self, page_size=10, page_number=0):
         """
-        Fetch the files associated with a specific annotation. The `annotation_id` and `project_id` 
+        Fetch the files associated with a specific annotation. The `annotation_id` and `project_id`
         must be set in the class instance.
 
         Parameters
@@ -365,11 +358,11 @@ class Annotation:
         -------
         tuple
             A tuple containing three elements:
-            - dict: 
+            - dict:
                 The API response with a list of files associated with the annotation.
-            - str or None: 
+            - str or None:
                 Error message if an error occurred, `None` otherwise.
-            - str: 
+            - str:
                 Status message indicating success or failure.
 
         Example
@@ -380,10 +373,9 @@ class Annotation:
         >>>     pprint(err)
         >>> else:
         >>>     pprint(files)
-        """ 
+        """
         path = f"/v1/annotations/{self.annotation_id}/files?projectId={self.project_id}&pageSize={page_size}&pageNumber={page_number}"
         resp = self.rpc.get(path=path)
-
         return handle_response(
             resp,
             "Annotation files fetched successfully",
@@ -392,7 +384,7 @@ class Annotation:
 
     def get_item_history(self, annotation_item_id):
         """
-        Fetch the annotation history for a specific item. The `annotation_id` and `project_id` 
+        Fetch the annotation history for a specific item. The `annotation_id` and `project_id`
         must be set in the class instance.
 
         Parameters
@@ -404,11 +396,11 @@ class Annotation:
         -------
         tuple
             A tuple containing three elements:
-            - dict: 
+            - dict:
                 The API response with the annotation history details.
-            - str or None: 
+            - str or None:
                 Error message if an error occurred, `None` otherwise.
-            - str: 
+            - str:
                 Status message indicating success or failure.
 
         Example
@@ -422,17 +414,15 @@ class Annotation:
         """
         path = f"/v1/annotations/{self.annotation_id}/{annotation_item_id}/annotation_history?projectId={self.project_id}"
         resp = self.rpc.get(path=path)
-
         return handle_response(
             resp,
             "Annotation history fetched successfully",
             "Could not fetch annotation history",
         )
-    
-    #TODO: Update the api call to fetch details using status
-    def list_items(self, page_size = 10, page_number = 0):
+
+    def list_items(self, page_size=10, page_number=0):
         """
-        Retrieve a paginated list of items associated with the annotation. The `annotation_id` and 
+        Retrieve a paginated list of items associated with the annotation. The `annotation_id` and
         `project_id` must be set in the class instance.
 
         Parameters
@@ -446,11 +436,11 @@ class Annotation:
         -------
         tuple
             A tuple containing three elements:
-            - dict: 
+            - dict:
                 The API response with the annotation items.
-            - str or None: 
+            - str or None:
                 Error message if an error occurred, `None` otherwise.
-            - str: 
+            - str:
                 Status message indicating success or failure.
 
         Raises
@@ -472,18 +462,14 @@ class Annotation:
                 "Annotation id not set for this dataset. Cannot perform the operation for annotation without annotation id"
             )
             sys.exit(0)
-            
-        #TODO: Implement the API call
         path = f"/v1/annotations/{self.annotation_id}/files?/v2/projectId={self.project_id}&pageSize={page_size}&pageNumber={page_number}"
         resp = self.rpc.get(path=path)
-
         return handle_response(
             resp,
             "Annotation items fetched successfully",
             "Could not fetch annotation items",
         )
-             
-    #TODO: Modify to update the entire annotation for an item for classification 
+
     def update_classification_item(
         self,
         file_id,
@@ -494,9 +480,10 @@ class Annotation:
         status,
         issues,
         label_time,
-        review_time):
+        review_time,
+    ):
         """
-        Update annotation data for a specific file. The `annotation_id` and `project_id` must 
+        Update annotation data for a specific file. The `annotation_id` and `project_id` must
         be set in the class instance.
 
         Parameters
@@ -530,11 +517,11 @@ class Annotation:
         -------
         tuple
             A tuple containing three elements:
-            - dict: 
+            - dict:
                 The API response confirming the update of the annotation item.
-            - str or None: 
+            - str or None:
                 Error message if an error occurred, `None` otherwise.
-            - str: 
+            - str:
                 Status message indicating success or failure.
 
         Example
@@ -552,7 +539,6 @@ class Annotation:
         >>> else:
         >>>     pprint(update_resp)
         """
-        #TODO: Implement the API call
         path = f"/v1/annotations/{self.annotation_id}/files/{file_id}/annotate?projectId={self.project_id}"
         payload = {
             "annotationId": self.annotation_id,
@@ -566,28 +552,31 @@ class Annotation:
             "reviewTime": review_time,
         }
         headers = {"Content-Type": "application/json"}
-        resp = self.rpc.put(path=path, headers=headers, payload=payload)
-        
+        resp = self.rpc.put(
+            path=path,
+            headers=headers,
+            payload=payload,
+        )
         return handle_response(
             resp,
             "Annotation updated successfully",
             "An error occured while updating annotation",
         )
-          
+
     def get_categories(self):
         """
-        Fetch categories for a specific annotation by its ID. The `annotation_id` must be set in 
+        Fetch categories for a specific annotation by its ID. The `annotation_id` must be set in
         the class instance.
 
         Returns
         -------
         tuple
             A tuple containing three elements:
-            - dict: 
+            - dict:
                 The API response with details about the categories.
-            - str or None: 
+            - str or None:
                 Error message if an error occurred, `None` otherwise.
-            - str: 
+            - str:
                 Status message indicating success or failure.
 
         Example
@@ -601,11 +590,12 @@ class Annotation:
         """
         path = f"/v1/annotations/{self.annotation_id}/categories"
         resp = self.rpc.get(path=path)
-
         return handle_response(
-            resp, "Categories fetched successfully", "Could not fetch categories"
+            resp,
+            "Categories fetched successfully",
+            "Could not fetch categories",
         )
-    
+
     def annotate_classification_item(
         self,
         file_id,
@@ -619,7 +609,7 @@ class Annotation:
         review_time,
     ):
         """
-        Add annotation data to a specific file. The `annotation_id` and `project_id` 
+        Add annotation data to a specific file. The `annotation_id` and `project_id`
         must be set in the class instance.
 
         Parameters
@@ -654,9 +644,9 @@ class Annotation:
         tuple
             A tuple containing three elements:
             - dict: The API response confirming the addition of the annotation item.
-            - str or None: 
+            - str or None:
                 Error message if an error occurred, `None` otherwise.
-            - str: 
+            - str:
                 Status message indicating success or failure.
 
         Example
@@ -687,8 +677,11 @@ class Annotation:
             "reviewTime": review_time,
         }
         headers = {"Content-Type": "application/json"}
-        resp = self.rpc.post(path=path, headers=headers, payload=payload)
-
+        resp = self.rpc.post(
+            path=path,
+            headers=headers,
+            payload=payload,
+        )
         return handle_response(
             resp,
             "Annotation added successfully",
@@ -703,7 +696,7 @@ class Annotation:
         new_version_description,
     ):
         """
-        Create or update a dataset based on annotation data. The `annotation_id` and `project_id` 
+        Create or update a dataset based on annotation data. The `annotation_id` and `project_id`
         must be set in the class instance.
 
         Parameters
@@ -721,11 +714,11 @@ class Annotation:
         -------
         tuple
             A tuple containing three elements:
-            - dict: 
+            - dict:
                 The API response confirming the creation or update of the dataset.
-            - str or None: 
+            - str or None:
                 Error message if an error occurred, `None` otherwise.
-            - str: 
+            - str:
                 Status message indicating success or failure.
 
         Example
@@ -741,7 +734,6 @@ class Annotation:
         >>>     pprint(dataset_resp)
         """
         path = f"/v1/annotations/{self.annotation_id}/create_dataset?projectId={self.project_id}"
-
         payload = {
             "annotationId": self.annotation_id,
             "isCreateNew": is_create_new,
@@ -751,8 +743,11 @@ class Annotation:
             "datasetDesc": "",
         }
         headers = {"Content-Type": "application/json"}
-        resp = self.rpc.post(path=path, headers=headers, payload=payload)
-
+        resp = self.rpc.post(
+            path=path,
+            headers=headers,
+            payload=payload,
+        )
         return handle_response(
             resp,
             "Annotation added successfully",
@@ -761,7 +756,7 @@ class Annotation:
 
     def add_label(self, labelname):
         """
-        Adds a new label for the annotation. The `annotation_id` and `project_id` 
+        Adds a new label for the annotation. The `annotation_id` and `project_id`
         must be set in the class instance.
 
         Parameters
@@ -777,9 +772,9 @@ class Annotation:
                 - `_id` (str): Unique identifier for the new label.
                 - `name` (str): Name of the label.
                 - `createdAt` (str): Timestamp when the label was created.
-            - str or None: 
+            - str or None:
                 Error message if an error occurred, `None` otherwise.
-            - str: 
+            - str:
                 Status message indicating success or failure.
 
         Raises
@@ -801,12 +796,17 @@ class Annotation:
                 "Annotation id not set for this annotation. Cannot download without annotation id"
             )
             sys.exit(0)
-
-        body = {"_idAnnotation": self.annotation_id, "name": labelname}
+        body = {
+            "_idAnnotation": self.annotation_id,
+            "name": labelname,
+        }
         headers = {"Content-Type": "application/json"}
         path = f"/v1/annotations/{self.annotation_id}/categories?projectId={self.project_id}"
-
-        resp = self.rpc.post(path=path, headers=headers, payload=body)
+        resp = self.rpc.post(
+            path=path,
+            headers=headers,
+            payload=body,
+        )
         return handle_response(
             resp,
             "Category added successfully",
@@ -815,7 +815,7 @@ class Annotation:
 
     def delete_item(self, annotation_item_id):
         """
-        Delete a specific annotation item. The `annotation_id` and `project_id` must be set 
+        Delete a specific annotation item. The `annotation_id` and `project_id` must be set
         in the class instance.
 
         Parameters
@@ -828,9 +828,9 @@ class Annotation:
         tuple
             A tuple containing three elements:
             - dict: The API response confirming the deletion of the annotation item.
-            - str or None: 
+            - str or None:
                 Error message if an error occurred, `None` otherwise.
-            - str: 
+            - str:
                 Status message indicating success or failure.
 
         Raises
@@ -852,12 +852,10 @@ class Annotation:
                 "Annotation id not set for this dataset. Cannot perform the deletion for annotation without annotation id"
             )
             sys.exit(0)
-
-        path = f"/v1/annotations/{self.annotation_id}/files/{annotation_item_id}?projectId={self.project_id}"  # check
-
+        path = f"/v1/annotations/{self.annotation_id}/files/{annotation_item_id}?projectId={self.project_id}"
         resp = self.rpc.delete(path=path)
         return handle_response(
             resp,
             "Annotation Item deleted successfully",
             "An error occured while deleting annotation item",
-        )
\ No newline at end of file
+        )
